JTW_2006_SLA: 2006 journey to work data, by SLA

Description Usage Format

Description

Origin-destination counts from the journey to work question in the Australian census.

"Q41: For the main job held last week, what was the person's work place address?

Usage

1

Format

An object of class data.table (inherits from data.frame) with 2085055 rows and 3 columns.


HughParsonage/journey.to.work1116 documentation built on May 28, 2019, 12:41 p.m.