Origin-destination counts from the journey to work question in the Australian census.
"Q41: For the main job held last week, what was the person's work place address?
For persons who usually worked from home, write the home address
For persons with no fixed place of work:
If the person usually travels to a depot to start work, write the depot address;
otherwise, write NONE in 'Suburb/Locality' box.
1 |
An object of class data.table (inherits from data.frame) with 2085055 rows and 3 columns.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.